﻿<?xml version="1.0" encoding="utf-8"?>
<!-- XSLT scheme for translating a Pepperi order XML to JDF
John Trap Canon Production Printing -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xs" version="1.0">
  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
  <xsl:template match="/">

<!-- extracting a part of the date from the order date. This will be used to create a valid creation date for PRISMAdirect -->
    <xsl:variable name="Date">
        <xsl:value-of select="substring-before(SalesTransaction/TransactionHeader/TransactionHeaderFields/Date,'Z')"/>
    </xsl:variable>

<!-- extracting the first and last name for easier linking in the JDF template -->
    <xsl:variable name="FirstName">
      <xsl:value-of select="substring-before(SalesTransaction/TransactionHeader/ContactPersonFields/ContactPersonFirstName,' ')"/>
    </xsl:variable>
    
    <xsl:variable name="LastName">
      <xsl:value-of select="substring-after(SalesTransaction/TransactionHeader/ContactPersonFields/ContactPersonLastName,' ')"/>
    </xsl:variable>
	
<!-- extracting the product from the line item -->	
    <xsl:variable name="Product">
      <xsl:value-of select="(SalesTransaction/TransactionLines/TransactionLine/ItemFields/ItemName)"/>
    </xsl:variable>

<!-- extracting the exact ProductName to link to a product in PRISMAdirect. Two ways, use the exact item/product name or a part of the item/product name -->		
	<xsl:variable name="ProductName">
      <xsl:choose>
        <xsl:when test="$Product = 'Corporate Business Card' ">CorpBusCard</xsl:when>
		<xsl:when test="contains($Product, 'Flyer')">Flyer</xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$Product"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
	
<!-- Use the ProductName to change the plexity setting -->		
	<xsl:variable name="Plexity">
      <xsl:choose>
          <xsl:when test="$ProductName ='Flyer'">
			      <xsl:value-of select="'OneSidedFront'"/>
          </xsl:when>
          <xsl:otherwise>
			      <xsl:value-of select="'TwoSidedFlipY'"/>
          </xsl:otherwise>
      </xsl:choose>    
    </xsl:variable>

<!-- extracting the OrderNumber for easier linking in the JDF template -->	
    <xsl:variable name="OrderNumber">
		<xsl:value-of select="(SalesTransaction/TransactionHeader/TransactionHeaderFields/WrntyID)"/>   
    </xsl:variable>    

<!-- extracting the exact content link from the download link-->  	
    <xsl:variable name="ContentLink">
      <xsl:value-of select="(SalesTransaction/TransactionLines/TransactionLine/ItemFields/ItemLink)" />
    </xsl:variable>

<!-- extracting the copies for easier linking in the JDF template -->
    <xsl:variable name="Copies">
		<xsl:value-of select="(SalesTransaction/TransactionLines/TransactionLine/ItemFields/ItemCaseQuantity)"/>   
    </xsl:variable>

<!-- extracting the UserID from the email address if there is UserID known from the external system. In this way you are able to do the accounting -->  
    <xsl:variable name="UserID">
        <xsl:choose>
          <xsl:when test="SalesTransaction/TransactionHeader/ContactPersonFields/ContactPersonEmail !=''">
			<xsl:value-of select="substring-before(SalesTransaction/TransactionHeader/ContactPersonFields/ContactPersonEmail,'@')"/>
          </xsl:when>
          <xsl:otherwise>
			<xsl:value-of select="'NoID'"/>
          </xsl:otherwise>
        </xsl:choose>    
    </xsl:variable>
	
<!-- This is where the JDF template starts -->      
  <JDF ID = "{$OrderNumber}" Type = "ProcessGroup" xmlns = "http://www.CIP4.org/JDFSchema_1_1" Types = "LayoutPreparation Imposition Interpreting Rendering DigitalPrinting Delivery Folding" Status = "Waiting" Version = "1.3" Category = "DigitalPrinting" SettingsPolicy = "MustHonor" JobID = "{$OrderNumber}" JobPartID = "jdfPart1">
    <AuditPool>
      <Created AgentName = "PEPPERI" AgentVersion = "1.0" TimeStamp = "{$Date}+01:00"/>
    </AuditPool>
    <Comment Name="WorkOrderNumber">PEP-<xsl:value-of select="$OrderNumber" />
    </Comment>
    <Comment Name="PartNumber">
      <xsl:value-of select="SalesTransaction/TransactionLines/TransactionLine/ItemFields/ItemUPC" />
    </Comment>
    <Comment Name="Description">
      <xsl:value-of select="$Product"/>
    </Comment>
	  <Comment Name="FinalCost"><xsl:value-of select="SalesTransaction/TransactionLines/TransactionLine/TransactionLineFields/TotalUnitsPriceAfterDiscount" /></Comment>
	  <Comment Name="Price"><xsl:value-of select="SalesTransaction/TransactionLines/TransactionLine/TransactionLineFields/TotalUnitsPriceAfterDiscount" /></Comment>
    <ResourcePool>
      <NodeInfo ID = "rNodeInfo1" Class = "Parameter" Status = "Available">
        <GeneralID IDUsage="ProductName" IDValue="{$ProductName}"/>
      </NodeInfo>
      <Contact Class="Parameter" ContactTypes="Customer" ID="rContactID" Status="Available" UserID="{$UserID}">
        <Company OrganizationName="{/SalesTransaction/TransactionHeader/AccountFields/AccountName}">
          <OrganizationalUnit>
            <xsl:value-of select="SalesTransaction/TransactionHeader/AccountFields/AccountName"/></OrganizationalUnit>
        </Company>
        <Person FamilyName="{$LastName}" FirstName="{$FirstName}"/>
		<ComChannel ChannelType="Phone" Locator="{/SalesTransaction/TransactionHeader/ContactPersonFields/ContactPersonPhone}"/>
		<ComChannel ChannelType="Email" Locator="{/SalesTransaction/TransactionHeader/ContactPersonFields/ContactPersonEmail}"/>
      </Contact>
	  <Contact Class="Parameter" ContactTypes="Delivery" ID="rDeliveryID" Status="Available">
			<Person FamilyName="{$LastName}" FirstName="{$FirstName}"/>
			<Address City="{/SalesTransaction/TransactionHeader/AccountFields/AccountCity}" Country="{/SalesTransaction/TransactionHeader/AccountFields/AccountCountry}" PostalCode="{/SalesTransaction/TransactionHeader/AccountFields/AccountZipCode}" Street="{/SalesTransaction/TransactionHeader/AccountFields/AccountStreet}"/>
	  </Contact>
      <CustomerInfo BillingCode="12345" Class="Parameter" CustomerID="CustomerID" CustomerJobName="{$ProductName}-{$OrderNumber}" ID="rCustomerInfo1" Status="Available">
        <ContactRef rRef="rContactID"/>
      </CustomerInfo>
	  <DeliveryParams Class="Parameter" ID="rDeliveryInfo" Method="ExpressMail" Status="Available">
		<ContactRef rRef="rDeliveryID"/>
	  </DeliveryParams>
      <RunList ID = "rRunList1" Status = "Available" Class = "Parameter">
        <LayoutElementRef rRef = "rLayoutElementID"/>
      </RunList>
      <Media ID = "rMedia1" Class = "Consumable" Status = "Available" DescriptiveName = "Media from product" />
      <LayoutElement ID = "rLayoutElementID" Status = "Available" Class = "Parameter">
        <FileSpec UserFileName = "{$ProductName}-PEPId{$OrderNumber}.pdf" URL = "{$ContentLink}" MimeType = "application/pdf"/>
      </LayoutElement>
      <LayoutPreparationParams ID = "rLayoutPreparationParams1" Class = "Parameter" Status = "Available" Sides = "{$Plexity}"/>
      <RenderingParams ID = "rRenderingParams1" Class = "Parameter" Status = "Available"/>
      <DigitalPrintingParams ID="rDigitalPrintingParams1" Class="Parameter" Status="Available" PartIDKeys="RunIndex" Collate="SheetSetAndJob" OutputBin="AutoSelect">
         <MediaRef rRef="rMedia1" />
      </DigitalPrintingParams>
      <ColorantControl ID = "CCID" Class = "Parameter" Status = "Available" ProcessColorModel = "DeviceCMYK" SettingsPolicy = "MustHonor"/>
      <Component ID = "rComponentFinalProduct" Status = "Unavailable" Class = "Quantity" ComponentType = "FinalProduct"/>
    </ResourcePool>
    <ResourceLinkPool>
      <CustomerInfoLink rRef = "rCustomerInfo1" Usage = "Input"/>
      <NodeInfoLink rRef = "rNodeInfo1" Usage = "Input"/>
      <RunListLink rRef = "rRunList1" Usage = "Input"/>
      <MediaLink rRef = "rMedia1" Usage = "Input"/>
      <LayoutPreparationParamsLink rRef = "rLayoutPreparationParams1" Usage = "Input"/>
      <RenderingParamsLink rRef = "rRenderingParams1" Usage = "Input"/>
      <DigitalPrintingParamsLink rRef = "rDigitalPrintingParams1" Usage = "Input"/>
      <ColorantControlLink rRef = "CCID" Usage = "Input"/>
      <ComponentLink rRef = "rComponentFinalProduct" Usage = "Output" Amount = "{$Copies}"/>
    </ResourceLinkPool>
  </JDF>
  </xsl:template>
</xsl:stylesheet>
