﻿<?xml version="1.0" encoding="utf-8"?>
<!-- XSLT scheme for translating a WooCommerce order XML to JDF
John Trap Canon Production Printing -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xs" version="1.0">
  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
  <xsl:template match="/">

<!-- extracting date and time from the order date. This will be used to create a valid creation date for PRISMAdirect -->
    <xsl:variable name="Date">
        <xsl:value-of select="substring-before(Orders/Order/OrderDate,' ')"/>
    </xsl:variable>

    <xsl:variable name="Time">
      <xsl:value-of select="substring-after(Orders/Order/OrderDate,' ')"/>
    </xsl:variable>
	
<!-- extracting the product from the line item -->
    <xsl:variable name="Product">
      <xsl:value-of select="(Orders/Order/OrderLineItems/OrderLineItem/Name)"/>
    </xsl:variable>
	
<!-- extracting the exact ProductName to link to a product in PRISMAdirect. Two ways, use the exact item/product name or a part of the item/product name -->	
    <xsl:variable name="ProductName">
      <xsl:choose>
        <xsl:when test="$Product = 'Corporate Business Card' ">CorpBusCard</xsl:when>
		<xsl:when test="contains($Product, 'Flyer')">Flyer</xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$Product"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

<!-- Use the ProductName to change the plexity setting -->		
	<xsl:variable name="Plexity">
        <xsl:choose>
          <xsl:when test="$ProductName ='Flyer'">
			      <xsl:value-of select="'OneSidedFront'"/>
          </xsl:when>
          <xsl:otherwise>
			      <xsl:value-of select="'TwoSidedFlipY'"/>
          </xsl:otherwise>
        </xsl:choose>    
    </xsl:variable>

<!-- extracting the exact content link from the download link-->    
    <xsl:variable name="ContentLink">
      <xsl:value-of select="substring-before(substring-after(Orders/Order/OrderLineItems/OrderLineItem/Link,'&quot;'),'&quot;')" />
    </xsl:variable>

<!-- correcting the overall copies if copies and quantity is used together in the product -->  
    <xsl:variable name="Copies">
        <xsl:choose>
          <xsl:when test="Orders/Order/OrderLineItems/OrderLineItem/Copies !=''">
			<xsl:value-of select="(Orders/Order/OrderLineItems/OrderLineItem/Copies) * (Orders/Order/OrderLineItems/OrderLineItem/Qty)"/>
          </xsl:when>
          <xsl:otherwise>
			<xsl:value-of select="Orders/Order/OrderLineItems/OrderLineItem/Qty"/>
          </xsl:otherwise>
        </xsl:choose>    
    </xsl:variable>

<!-- extracting the UserID from the email address if there is UserID known from the external system. In this way you are able to do the accounting -->  
    <xsl:variable name="UserID">
        <xsl:choose>
          <xsl:when test="Orders/Order/BillingEmail !=''">
			<xsl:value-of select="substring-before(Orders/Order/BillingEmail,'@')"/>
          </xsl:when>
          <xsl:otherwise>
			<xsl:value-of select="'NoID'"/>
          </xsl:otherwise>
        </xsl:choose>    
    </xsl:variable>
    	
<!-- This is where the JDF template starts -->   
  <JDF ID = "{Orders/Order/OrderKey}-{Orders/Order/OrderNumber}" Type = "ProcessGroup" xmlns = "http://www.CIP4.org/JDFSchema_1_1" Types = "LayoutPreparation Imposition Interpreting Rendering DigitalPrinting Delivery Folding" Status = "Waiting" Version = "1.3" Category = "DigitalPrinting" SettingsPolicy = "MustHonor" JobID = "{Orders/Order/OrderKey}" JobPartID = "jdfPart1">
    <AuditPool>
      <Created AgentName = "W2P" AgentVersion = "1.0" TimeStamp = "{$Date}T{$Time}:00+01:00"/>
    </AuditPool>
    <Comment Name="WorkOrderNumber">WOO-<xsl:value-of select="Orders/Order/OrderNumber" />
    </Comment>
    <Comment Name="PartNumber">
      <xsl:value-of select="Orders/Order/OrderLineItems/OrderLineItem/Sku" />
    </Comment>
    <Comment Name="Description">
      <xsl:value-of select="$Product"/>
    </Comment>
	<Comment Name="FinalCost"><xsl:value-of select="Orders/Order/OrderTotalAmount" /></Comment>
	<Comment Name="Price"><xsl:value-of select="Orders/Order/OrderTotalAmount" /></Comment>
    <ResourcePool>
      <NodeInfo ID = "rNodeInfo1" Class = "Parameter" Status = "Available">
        <GeneralID IDUsage="ProductName" IDValue="{$ProductName}"/>
      </NodeInfo>
      <Contact Class="Parameter" ContactTypes="Customer" ID="rContactID" Status="Available" UserID="{$UserID}">
        <Company OrganizationName="{/Orders/Order/BillingCompany}">
          <OrganizationalUnit/>
        </Company>
        <Person FamilyName="{/Orders/Order/BillingLastName}" FirstName="{/Orders/Order/BillingFirstName}"/>
		<ComChannel ChannelType="Phone" Locator="{/Orders/Order/BillingPhone}"/>
		<ComChannel ChannelType="Email" Locator="{/Orders/Order/BillingEmail}"/>
      </Contact>
	  <Contact Class="Parameter" ContactTypes="Delivery" ID="rDeliveryID" Status="Available">
			<Person FamilyName="{/Orders/Order/ShippingLastName}" FirstName="{/Orders/Order/ShippingFirstName}"/>
			<Address City="{/Orders/Order/ShippingCity}" Country="{/Orders/Order/ShippingCountry}" PostalCode="{/Orders/Order/ShippingPostcode}" Street="{/Orders/Order/ShippingAddress}"/>
	  </Contact>
      <CustomerInfo BillingCode="12345" Class="Parameter" CustomerID="CustomerID" CustomerJobName="{$ProductName}-{Orders/Order/OrderNumber}" ID="rCustomerInfo1" Status="Available">
        <ContactRef rRef="rContactID"/>
      </CustomerInfo>
	  <DeliveryParams Class="Parameter" ID="rDeliveryInfo" Method="ExpressMail" Status="Available">
		<ContactRef rRef="rDeliveryID"/>
	  </DeliveryParams>
      <RunList ID = "rRunList1" Status = "Available" Class = "Parameter">
        <LayoutElementRef rRef = "rLayoutElementID"/>
      </RunList>
      <Media ID = "rMedia1" Class = "Consumable" Status = "Available" DescriptiveName = "Media from product" />
      <LayoutElement ID = "rLayoutElementID" Status = "Available" Class = "Parameter">
        <FileSpec UserFileName = "{$ProductName}-WOOId{Orders/Order/OrderNumber}.pdf" URL = "{$ContentLink}" MimeType = "application/pdf"/>
      </LayoutElement>
      <LayoutPreparationParams ID = "rLayoutPreparationParams1" Class = "Parameter" Status = "Available" Sides = "{$Plexity}"/>
      <RenderingParams ID = "rRenderingParams1" Class = "Parameter" Status = "Available"/>
      <DigitalPrintingParams ID="rDigitalPrintingParams1" Class="Parameter" Status="Available" PartIDKeys="RunIndex" Collate="SheetSetAndJob" OutputBin="AutoSelect">
         <MediaRef rRef="rMedia1" />
      </DigitalPrintingParams>
      <ColorantControl ID = "CCID" Class = "Parameter" Status = "Available" ProcessColorModel = "DeviceCMYK" SettingsPolicy = "MustHonor"/>
      <Component ID = "rComponentFinalProduct" Status = "Unavailable" Class = "Quantity" ComponentType = "FinalProduct"/>
    </ResourcePool>
    <ResourceLinkPool>
      <CustomerInfoLink rRef = "rCustomerInfo1" Usage = "Input"/>
      <NodeInfoLink rRef = "rNodeInfo1" Usage = "Input"/>
      <RunListLink rRef = "rRunList1" Usage = "Input"/>
      <MediaLink rRef = "rMedia1" Usage = "Input"/>
      <LayoutPreparationParamsLink rRef = "rLayoutPreparationParams1" Usage = "Input"/>
      <RenderingParamsLink rRef = "rRenderingParams1" Usage = "Input"/>
      <DigitalPrintingParamsLink rRef = "rDigitalPrintingParams1" Usage = "Input"/>
      <ColorantControlLink rRef = "CCID" Usage = "Input"/>
      <ComponentLink rRef = "rComponentFinalProduct" Usage = "Output" Amount = "{$Copies}"/>
    </ResourceLinkPool>
  </JDF>
  </xsl:template>
</xsl:stylesheet>
